@@ -15,7 +15,7 @@ if sys.version_info < (3, 5):
     )
     sys.exit(1)
 
-VERSION = '0.1.19'
+VERSION = '0.1.20'
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -50,6 +50,7 @@ def discover(debug: int):
     sock.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
     sock.settimeout(5)
     found_devices = {}
+    _LOGGER.info("msmart version: {}".format(VERSION))
     _LOGGER.info(
         "Discovering devices with UDP Broadcast, press CTRL-C to quit...")
     for i in range(10):
@@ -62,21 +63,18 @@ def discover(debug: int):
                 if len(data) >= 104 and (data[:2].hex() == '5a5a' or data[8:10].hex() == '5a5a') and m_ip not in found_devices:
                     _LOGGER.info("Midea Local Data {} {}".format(m_ip, data.hex()))
                     if data[8:10].hex() == '5a5a':
-                        data = data[8:]
+                        data = data[8:-16]
                     m_id = convert_device_id_int(data[20:26].hex())
                     found_devices[m_ip] = m_id
-                    if data[8:10].hex() == '5a5a':
-                        encrypt_data = data[40:]
-                    else:
-                        encrypt_data = data[40:40+64]
+                    encrypt_data = data[40:-16]
                     reply = _security.aes_decrypt(encrypt_data)
 
                     m_sn = reply[14:14+26].decode("utf-8")
-                    m_ssid = reply[14+27:].decode("utf-8")
+                    # ssid like midea_xx_xxxx net_xx_xxxx
+                    m_ssid = reply[14+27:14+27+13].decode("utf-8")
                     m_type = m_ssid.split('_')[1]
                     
-                    if m_type == 'ac':
-                        m_support = support_test(m_ip, int(m_id))
+                    m_support = support_test(m_ip, int(m_id))
 
                     _LOGGER.info(
                         "*** Found a {} '0x{}' at {} - id: {} - sn: {} - ssid: {}".format(m_support, m_type, m_ip, m_id, m_sn, m_ssid))
